@@ -44,6 +44,8 @@ from lino.utils import dblogger
 from lino.utils import mti
 from lino.utils.ssin import generate_ssin
 
+from lino.modlib.cal.utils import DurationUnits    
+
 #~ from django.contrib.auth import models as auth
 #~ from lino.modlib.users import models as auth
 #~ from lino.modlib.contacts.utils import Gender
@@ -178,13 +180,60 @@ def unused_coachings(p,type,coach1,coach2,coached_from,coached_until=None):
 
 def objects():
     
+    guest_role = Instantiator('cal.GuestRole').build
+    obj = guest_role(email_template="Visitor.eml.html",**babel_values('name',
+          de="Besucher",
+          fr="Visiteur",
+          en="Visitor",
+          et="Külaline",
+          ))
+    yield obj
+    settings.SITE.site_config.update(client_guestrole=obj)
+    
+    obj = guest_role(**babel_values('name',
+          de="Kollege",
+          fr="Collègue",
+          en="Colleague",
+          et="Kolleeg",
+          ))
+    yield obj
+    settings.SITE.site_config.update(team_guestrole=obj)
+    
+    yield guest_role(**babel_values('name',
+          de=u"Vorsitzender",
+          fr=u"Président",
+          en=u"Presider",
+          et=u"Eesistuja",
+          ))
+    yield guest_role(**babel_values('name',
+          de=u"Protokollführer",
+          fr=u"Greffier",
+          en=u"Reporter",
+          et=u"Sekretär",
+          ))
+    
+    
     calendar = Instantiator('cal.Calendar').build
-    #~ yield calendar(**babel_values('name',
-          #~ de=u"Klientengespräche intern",
-          #~ fr=u"Rencontres internes avec client",
-          #~ en=u"Internal meetings with client",
-          #~ ))
-    yield calendar(color=1,**babel_values('name',
+    obj = calendar(color=20,invite_client=True,**babel_values('name',
+          de="Klientengespräche intern",
+          fr="Rencontres internes avec client",
+          en="Internal meetings with client",
+          ))
+    yield obj
+    settings.SITE.site_config.update(client_calender=obj)
+    
+    exam_policy = Instantiator('isip.ExamPolicy','every',every_unit=DurationUnits.months).build
+    yield exam_policy(1,calendar=obj,start_time="9:00",**babel_values('name',en='every month',de=u'monatlich',fr=u"mensuel"))
+    yield exam_policy(2,calendar=obj,start_time="9:00",**babel_values('name',en='every 2 months',de=u'zweimonatlich',fr=u"bimensuel"))
+    yield exam_policy(3,calendar=obj,start_time="9:00",**babel_values('name',en='every 3 months',de=u'alle 3 Monate',fr=u"tous les 3 mois"))
+    exam_policy = Instantiator('isip.ExamPolicy','every',every_unit=DurationUnits.weeks).build
+    yield exam_policy(2,calendar=obj,start_time="9:00",**babel_values('name',en='every 2 weeks',de=u'zweiwöchentlich',fr=u"hebdomadaire"))
+    exam_policy = Instantiator('isip.ExamPolicy').build
+    yield exam_policy(**babel_values('name',en='other',de="andere",fr="autre"))
+        
+    
+        
+    yield calendar(color=1,invite_client=True,**babel_values('name',
           de=u"Klientengespräche extern",
           fr=u"Rencontres client externes",
           en=u"External meetings with client",
@@ -367,7 +416,8 @@ def objects():
     #~ yield country('SUHH',"Soviet Union")
     
     eupen = City.objects.get(name__exact='Eupen')
-    stvith = City.objects.get(zip_code__exact='4780')
+    #~ stvith = City.objects.get(zip_code__exact='4780')
+    stvith = City.objects.get(name__in=('Sankt Vith','Saint-Vith'))
     kettenis = City.objects.get(name__exact='Kettenis')
     vigala = City.objects.get(name__exact='Vigala')
     ee = countries.Country.objects.get(pk='EE')
@@ -478,7 +528,7 @@ def objects():
     
     gerd = person(first_name="Gerd",
       last_name="Xhonneux",city=kettenis,
-      email='gerd@example.com',
+      email=settings.SITE.demo_email, # 'gerd@example.com'
       country='BE',gender=mixins.Genders.male)
     yield gerd
     yield role(company=cpas,person=gerd,type=4)
@@ -560,7 +610,7 @@ def objects():
     #~ yield User(username='gerd',partner=gerd,profile='900')
     
     melanie = person(first_name="Mélanie",last_name="Mélard",
-        email='melanie@example.com',
+        email=settings.SITE.demo_email, # 'melanie@example.com',
         city=eupen,country='BE',gender=mixins.Genders.female,
         language='fr')
     yield melanie
@@ -568,19 +618,26 @@ def objects():
     yield melanie
     
     hubert = person(first_name=u"Hubert",last_name=u"Huppertz",
-        email='hubert@example.com',
+        email=settings.SITE.demo_email, # 'hubert@example.com',
         city=eupen,country='BE',gender=mixins.Genders.male)
     yield hubert
     hubert = users.User(username="hubert",partner=hubert,profile='100') 
     yield hubert
     
     alicia = person(first_name=u"Alicia",last_name=u"Allmanns",
-        email='alicia@example.com',
+        email=settings.SITE.demo_email, # 'alicia@example.com',
         city=eupen,country='BE',gender=mixins.Genders.female,language='fr')
     yield alicia
     alicia = users.User(username="alicia",partner=alicia,profile='100') 
     yield alicia
     
+    theresia = person(first_name=u"Theresia",last_name=u"Thelen",
+        email=settings.SITE.demo_email, # 'theresia@example.com',
+        city=eupen,country='BE',gender=mixins.Genders.female,language='de')
+    yield theresia
+    theresia = users.User(username="theresia",partner=theresia,profile='210') 
+    yield theresia
+    
     yield Authority(user=alicia,authorized=hubert)
     yield Authority(user=alicia,authorized=melanie)
     yield Authority(user=hubert,authorized=melanie)
@@ -998,7 +1055,7 @@ def objects():
                     kw.update(ending=ENDINGS.pop())
                 yield pcsw.Coaching(**kw)
                 
-    for i,p in enumerate(pcsw.Partner.objects.all()):
+    for i,p in enumerate(contacts.Partner.objects.all()):
         if i % 10 == 0:
             p.is_obsolete = True
             p.save()
