@@ -300,24 +300,28 @@ def PAR_model(data):
     - Neuzugänge (Attribut N) sind ebenfalls immer Klienten
     
     """
-    nb2 = data.get('NB2',False)
-    if nb2: # SSIN
-        if nb2.strip() == '0':
-            data['NB2'] = ''
-        else:
+    has_first_name = len(data.get('FIRME','').split()) > 1
+    if has_first_name:
+        nb2 = data.get('NB2',False)
+        if nb2: # SSIN
+            if nb2.strip() == '0':
+                data['NB2'] = ''
+            else:
+                return Client
+        if data.get('NB1',False): # gesdos-Nr
             return Client
-    if data.get('NB1',False): # gesdos-Nr
-        return Client
-    attribs = data.get('ATTRIB',False)
-    if attribs and 'N' in attribs: # newcomer
-        return Client
-    #~ if data.get('IDUSR',False): # Sozi
-        #~ return Client
+        attribs = data.get('ATTRIB',False)
+        if attribs and 'N' in attribs: # newcomer
+            return Client
+        #~ if data.get('IDUSR',False): # Sozi
+            #~ return Client
     if data.get('NOTVA',False):
         return Company
     if data.get('ALLO','') in (u"Eheleute",):
         return Household
-    return Person
+    if has_first_name:
+        return Person
+    return Partner
     
 
     
@@ -567,39 +571,6 @@ class PAR(Controller):
                         
                     try:
                         coaching = pcsw.Coaching.objects.get(client=obj,primary=True)
-                        watcher = dd.ChangeWatcher(coaching)
-                        if u is None or u != coaching.user:
-                            """
-                            If the coach has changed, maintain the old coaching in history.
-                            """
-                            coaching.primary = False
-                            coaching.end_date = datetime.date.today()
-                        else:
-                            if obj.client_state == pcsw.ClientStates.coached:
-                                coaching.end_date = None # 1990
-                            else:
-                                coaching.end_date = LONG_TIME_AGO
-                                
-                            coaching.type = u.coaching_type
-                            if coaching.start_date is None:
-                                coaching.start_date = obj.created
-                            
-                        if watcher.is_dirty():
-                            coaching.save()
-                            watcher.send_update(REQUEST)
-                            
-                        if u is not None and coaching.user != u:
-                            """
-                            create a new coaching 
-                            """
-                            coaching = pcsw.Coaching(
-                                client=obj,primary=True,
-                                user=u,
-                                type=u.coaching_type,
-                                start_date=datetime.date.today())
-                            coaching.save()
-                            dd.pre_ui_create.send(sender=coaching,request=REQUEST)
-
                     except pcsw.Coaching.DoesNotExist,e:
                         try:
                             coaching = pcsw.Coaching.objects.get(client=obj,user=u,end_date__isnull=True)
@@ -618,16 +589,48 @@ class PAR(Controller):
                                 #~ changes.log_create(REQUEST,coaching)
                         except Exception,e:
                             raise Exception("More than one primary coaching for %r by %r" % (obj,u))
+                            
                     except Exception,e:
+                        
                         raise Exception("More than one primary coaching for %r : %s" % (obj,e))
+                        
+                    else:
+                        watcher = dd.ChangeWatcher(coaching)
+                        if u is None or u != coaching.user:
+                            """
+                            If the coach has changed, maintain the old coaching in history.
+                            """
+                            coaching.primary = False
+                            coaching.end_date = datetime.date.today()
+                        else:
+                            coaching.type = u.coaching_type
+                            if coaching.start_date is None:
+                                coaching.start_date = obj.created
+                                
+                            if obj.client_state == pcsw.ClientStates.coached:
+                                coaching.end_date = None # 1990
+                            else:
+                                #~ coaching.end_date = LONG_TIME_AGO
+                                coaching.end_date = coaching.start_date
+                                
+                            
+                        if watcher.is_dirty():
+                            coaching.full_clean()
+                            coaching.save()
+                            watcher.send_update(REQUEST)
+                            
+                        if u is not None and coaching.user != u:
+                            """
+                            create a new coaching 
+                            """
+                            coaching = pcsw.Coaching(
+                                client=obj,primary=True,
+                                user=u,
+                                type=u.coaching_type,
+                                start_date=datetime.date.today())
+                            coaching.save()
+                            dd.pre_ui_create.send(sender=coaching,request=REQUEST)
 
-                    #~ else:
-                        #~ try:
-                            #~ coaching = pcsw.Coaching.objects.get(client=obj,primary=True)
-                            #~ dd.pre_ui_delete.send(sender=coaching,request=REQUEST)
-                            #~ coaching.delete()
-                        #~ except pcsw.Coaching.DoesNotExist,e:
-                            #~ pass
                         
         elif obj.__class__ is Company:
             #~ obj.prefix = data.get('ALLO','')
@@ -640,6 +643,9 @@ class PAR(Controller):
             mapper.update(name='FIRME')
             if data.get('ALLO','') == "Eheleute":
                 obj.type = households_Type.objects.get(pk=1)
+        elif obj.__class__ is Partner:
+            mapper.update(name='FIRME')
+            mapper.update(prefix='ALLO')
             
         Controller.applydata(self,obj,data,**mapper)
         
@@ -894,7 +900,7 @@ def process_line(ln):
     if ctrl is None:
         #~ raise Exception("%(alias)s : no such controller." % kw)
         #~ logger.debug("Ignoring change %(time)s for %(alias)s:%(id)s",kw['time'],kw['alias'],kw['id'])
-        logger.info("Ignoring change %(time)s for %(alias)s:%(id)s",kw)
+        dblogger.info("Ignoring change %(time)s for %(alias)s:%(id)s",kw)
         return
     #~ kw['data'] = ctrl.prepare_data(kw['data'])
     m = getattr(ctrl,kw['method'])
@@ -952,14 +958,14 @@ def main(*args,**options):
         raise CommandError('Please specify the path to your TIM changelog directory')
     data_dir = args[0]
     #~ msg = "Started watch_tim %s on %s ..."
-    #~ logger.info(msg,data_dir)
+    #~ dblogger.info(msg,data_dir)
     #~ dblogger.info(msg,lino.__version__,data_dir)
     
     settings.SITE.startup() 
         
     #~ def goodbye():
         #~ msg = "Stopped watch_tim %s on %s ..."
-        #~ logger.info(msg,data_dir)
+        #~ dblogger.info(msg,data_dir)
         #~ dblogger.info(msg,lino.__version__,data_dir)
     #~ # signal.signal(signal.SIGTERM,on_SIGTERM)
     #~ atexit.register(goodbye)
@@ -987,7 +993,8 @@ class Command(DaemonCommand):
     #~ preserve_loggers = (logger,dblogger.logger)
     preserve_loggers = [dblogger.logger]
     
-    def handle_daemon(self, *args, **options):
+    #~ def handle_daemon(self, *args, **options):
+    def handle(self, *args, **options):
         main(*args,**options)
 
 
