@@ -76,22 +76,13 @@ from lino.core import actions
 from lino.modlib.contacts.utils import street2kw
 from lino.modlib.contacts import models as contacts
 
-#~ from lino.modlib.notes import models as notes
-#~ from lino.modlib.links import models as links
-#~ from lino.modlib.uploads import models as uploads
-#~ from lino.modlib.cal import models as cal
-#~ from lino.modlib.users import models as users
-#~ from lino.modlib.countries.models import CountryCity
-#~ from lino.modlib.cal.models import DurationUnits, update_reminder
-#~ from lino.modlib.properties import models as properties
-#~ from lino_welfare.modlib.cv import models as cv
-#~ from lino.modlib.contacts.models import Contact
 from lino.core.dbutils import resolve_model, UnresolvedModel
 
 households = dd.resolve_app('households')
-cal = dd.resolve_app('cal')
+#~ cal = dd.resolve_app('cal')
 properties = dd.resolve_app('properties')
 countries = dd.resolve_app('countries')
+contacts = dd.resolve_app('contacts')
 cv = dd.resolve_app('cv')
 uploads = dd.resolve_app('uploads')
 users = dd.resolve_app('users')
@@ -103,22 +94,6 @@ courses = dd.resolve_app('courses')
 #~ newcomers = dd.resolve_app('newcomers')
 
 
-ui = dd.resolve_app('ui')
-
-class SiteConfig(ui.SiteConfig,isip.Signers):
-    """
-    This adds the :class:`lino_welfare.modlib.isip.models.Signers` 
-    mixin to Lino's standard SiteConfig.
-    
-    This trick having ``"ui.SiteConfig"`` in :attr:`lino.Lino.override_modlib_models`.
-    
-    """
-    class Meta:
-        app_label = 'ui'
-
-dd.update_field(SiteConfig,'signer1', blank=True,null=True)
-dd.update_field(SiteConfig,'signer2', blank=True,null=True)
-
 
 def customize_users():
   
@@ -139,7 +114,7 @@ def customize_siteconfig():
     Injects application-specific fields to :class:`SiteConfig <lino.models.SiteConfig>`.
     """
     
-    dd.inject_field('ui.SiteConfig',
+    dd.inject_field('system.SiteConfig',
         'job_office',
         models.ForeignKey('contacts.Company',
             blank=True,null=True,
@@ -148,14 +123,14 @@ def customize_siteconfig():
             help_text="""The Company whose contact persons 
             will be choices for `Person.job_office_contact`."""))
         
-    dd.inject_field('ui.SiteConfig',
+    dd.inject_field('system.SiteConfig',
         'residence_permit_upload_type',
         models.ForeignKey("uploads.UploadType",
             blank=True,null=True,
             verbose_name=_("Upload Type for residence permit"),
             related_name='residence_permit_sites'))
         
-    dd.inject_field('ui.SiteConfig',
+    dd.inject_field('system.SiteConfig',
         'work_permit_upload_type',
         #~ UploadType.objects.get(pk=2)
         models.ForeignKey("uploads.UploadType",
@@ -163,7 +138,7 @@ def customize_siteconfig():
             verbose_name=_("Upload Type for work permit"),
             related_name='work_permit_sites'))
 
-    dd.inject_field('ui.SiteConfig',
+    dd.inject_field('system.SiteConfig',
         'driving_licence_upload_type',
         models.ForeignKey("uploads.UploadType",
             blank=True,null=True,
@@ -360,12 +335,12 @@ def site_setup(site):
         #~ detail_layout = HouseholdDetail()
         
 
-    site.modules.lino.Home.set_detail_layout("""
-    quick_links:80x1
-    welcome
-    pcsw.UsersWithClients:80x8
-    coming_reminders:40x16 missed_reminders:40x16
-    """)
+    #~ site.modules.lino.Home.set_detail_layout("""
+    #~ quick_links:80x1
+    #~ welcome
+    #~ pcsw.UsersWithClients:80x8
+    #~ coming_reminders:40x16 missed_reminders:40x16
+    #~ """)
     
     site.modules.households.Households.set_detail_layout(box3="""
     country region
@@ -376,7 +351,7 @@ def site_setup(site):
     """)
     
     
-    site.modules.ui.SiteConfigs.set_detail_layout("""
+    site.modules.system.SiteConfigs.set_detail_layout("""
     site_company system_note_type default_build_method 
     next_partner_id:20 job_office debts_bailiff_type master_budget
     signer1 signer2
@@ -386,6 +361,7 @@ def site_setup(site):
     """,constants="""
     propgroup_skills propgroup_softskills propgroup_obstacles
     residence_permit_upload_type work_permit_upload_type driving_licence_upload_type
+    client_calender client_guestrole team_guestrole
     """)
     
     site.modules.properties.Properties.set_detail_layout("""
@@ -431,8 +407,8 @@ def site_setup(site):
     """,window_size=(60,'auto'))
 
 
-    site.modules.contacts.Partners.set_detail_layout(pcsw.PartnerDetail())
-    site.modules.contacts.Companies.set_detail_layout(pcsw.CompanyDetail())
+    site.modules.contacts.Partners.set_detail_layout(contacts.PartnerDetail())
+    site.modules.contacts.Companies.set_detail_layout(contacts.CompanyDetail())
     #~ site.modules.contacts.Persons.set_detail_layout(PersonDetail())
     #~ for T in (site.modules.contacts.Partners,
             #~ site.modules.contacts.Persons,
@@ -442,28 +418,6 @@ def site_setup(site):
     site.modules.contacts.Partners.add_detail_tab('changes','changes.ChangesByMaster')
 
     
-    site.modules.cal.Events.set_detail_layout("general more")
-    site.modules.cal.Events.add_detail_panel("general","""
-    calendar summary project 
-    start end user assigned_to
-    room priority access_class transparent #rset 
-    owner workflow_buttons
-    description GuestsByEvent 
-    """,_("General"))
-    site.modules.cal.Events.add_detail_panel("more","""
-    id created:20 modified:20  
-    outbox.MailsByController postings.PostingsByController
-    """,_("More"))
-    
-    site.modules.cal.Events.set_insert_layout("""
-    summary 
-    start end 
-    calendar project 
-    """,
-    start="start_date start_time",
-    end="end_date end_time",
-    window_size=(60,'auto'))
-    
     #~ site.modules.users.Users.set_detail_layout(box2 = """
     #~ level
     #~ integ_level
@@ -558,7 +512,6 @@ customize_users()
   
 
 
-
 def setup_workflows(site):
 
     #~ ClientStates.newcomer.add_transition(states='refused coached invalid former',user_groups='newcomers')
@@ -584,7 +537,6 @@ def setup_workflows(site):
         user_groups='newcomers')
     #~ ClientStates.add_transition('new','refused',user_groups='newcomers')
 
-            
 
 
 #~ def setup_main_menu(site,ui,profile,m): 
