@@ -695,6 +695,14 @@ Wenn hier ein Betrag steht, darf "Verteilen" nicht angekreuzt sein.
     #~ circa todo remark description periods monthly_rate
     #~ """.split()
 
+    def get_siblings(self):
+        """
+        Like super(), but adds account_type. 
+        E.g. the Up/Down methods should work only within a given account_type.
+        """
+        #~ return super(Entry,self).get_siblings().filter(account_type=self.account_type)
+        return self.__class__.objects.filter(budget=self.budget,account_type=self.account_type).order_by('seqno')
+        
     @chooser()
     def account_choices(cls,account_type):
         #~ print '20120918 account_choices', account_type
@@ -817,8 +825,8 @@ class EntriesByBudget(Entries):
     Base class for the tables used to edit Entries by budget.
     """
     master_key = 'budget'
-    column_names = "account description amount actor:10 periods:10 remark move_buttons seqno todo"
-    hidden_columns = "seqno"
+    column_names = "account description amount actor:10 periods:10 remark move_buttons:8 seqno todo id"
+    hidden_columns = "seqno id"
     auto_fit_column_widths = True
     required = dd.required(user_groups='debts')
     #~ required_user_level = None
@@ -835,11 +843,11 @@ class IncomesByBudget(EntriesByBudget,EntriesByType):
 class LiabilitiesByBudget(EntriesByBudget,EntriesByType):
     "Liabilities By Budget"
     _account_type = AccountTypes.liabilities
-    column_names = "account partner remark amount actor:10 bailiff distribute monthly_rate todo seqno"
+    column_names = "account partner remark amount actor:10 bailiff distribute monthly_rate move_buttons:8 todo seqno id"
     
 class AssetsByBudget(EntriesByBudget,EntriesByType):
     _account_type = AccountTypes.assets
-    column_names = "account remark amount actor todo seqno"
+    column_names = "account remark amount actor move_buttons:8 todo seqno id"
 
 
 #~ class PrintEntriesByBudget(EntriesByBudget,EntriesByType):
@@ -1269,12 +1277,20 @@ def unused_setup_my_menu(site,ui,profile,m):
     m  = m.add_menu("debts",MODULE_LABEL)
     m.add_action(MyBudgets)
   
-def setup_config_menu(site,ui,profile,m): 
+def setup_config_menu(site,ui,profile,m):
     m  = m.add_menu("debts",MODULE_LABEL)
-    if site.site_config.master_budget:
-        fld = site.modules.ui.SiteConfig._meta.get_field('master_budget')
-        m.add_instance_action(site.site_config.master_budget,
-            label=unicode(fld.verbose_name))
+    mb = site.site_config.master_budget
+    if mb is not None:
+        """
+        the following line is to specify user permissions: non-manager 
+        debts agents users should have this command.
+        """
+        #~ mb._detail_action = MyBudgets.get_url_action('detail_action')
+        # (TODO: find a more elegant solution)
+        
+        fld = site.modules.system.SiteConfig._meta.get_field('master_budget')
+        m.add_instance_action(mb,label=unicode(fld.verbose_name),
+            action=MyBudgets.detail_action)
     #~ if user.profile.debts_level < UserLevels.manager: 
         #~ return
     #~ m.add_action(Accounts)
@@ -1285,7 +1301,7 @@ def setup_config_menu(site,ui,profile,m):
 def setup_explorer_menu(site,ui,profile,m):
     #~ if user.profile.debts_level < UserLevels.manager:
         #~ return
-    m  = m.add_menu("debts",MODULE_LABEL)
+    m = m.add_menu("debts",MODULE_LABEL)
     m.add_action(Budgets)
     m.add_action(Entries)
     #~ m.add_action(Debts)
@@ -1319,7 +1335,7 @@ def customize_accounts():
 customize_accounts()
 
 
-dd.inject_field('ui.SiteConfig',
+dd.inject_field('system.SiteConfig',
     'debts_bailiff_type',
     models.ForeignKey("pcsw.ClientContactType",
         blank=True,null=True,
@@ -1327,7 +1343,7 @@ dd.inject_field('ui.SiteConfig',
         related_name='bailiff_type_sites',
         help_text=_("Client contact type for Bailiff.")))
     
-dd.inject_field('ui.SiteConfig',
+dd.inject_field('system.SiteConfig',
     'master_budget',
     models.ForeignKey("debts.Budget",
         blank=True,null=True,
