@@ -6,16 +6,10 @@ from lino_welfare.settings import *
 class Site(Site):
   
     title = "Lino-Welfare demo"
-    #~ languages = ['en']
-    languages = 'de fr nl'
-    #~ languages = ['de','fr']
-    #~ languages = ['fr','de']
-    #~ languages = ['de']
     #~ use_jasmine = True
-    use_davlink = False
+    #~ use_davlink = False
     use_extensible = True
-    use_eid_jslib = False
-    remote_user_header = None # 20121003
+    #~ remote_user_header = None # 20121003
         
     def is_imported_partner(self,obj):
         if obj.id is not None and (obj.id > 110 and obj.id < 121):
