@@ -420,7 +420,7 @@ Belgique""")
         check_disabled(p,df,'id first_name last_name bank_account1')
         check_enabled(p,df,'gsm')
                     
-        h = pcsw.Household(name="Test Household")
+        h = households.Household(name="Test Household")
         h.save()
         df = households.Households.disabled_fields(h,None)
         #~ print df
@@ -478,6 +478,9 @@ Belgique""")
  **Restbetrag für Kredite und Zahlungsrückstände**         **-1 013,67**
 ========================================================= ===============
 """)
+        settings.SITE.site_config.master_budget = b1
+        settings.SITE.site_config.save()
+        
         
         #~ b2 = b1.duplicate()
         b2 = ses.run(b1.duplicate)
@@ -589,6 +592,7 @@ Belgique""")
         obj = accounts.Account.objects.get(group=ag)
         self.assertEqual(obj.name,"TestAccount")
         
+        
         def menu_test(username,expected,debug=False):
             ses = settings.SITE.login(username) 
             mnu = settings.SITE.get_site_menu(None,ses.get_user().profile)
@@ -607,7 +611,7 @@ Belgique""")
   - Postsendungen : Meine Postsendungen, Bereit für Ausdruck, Gedruckte Postsendungen, Ausgegangene Postsendungen
   - Meine Notizen
 
-- Kalender : Kalender, Termine, -, Meine Aufgaben, To-Do-Liste, -, Meine Anwesenheiten, Meine erhaltenen Einladungen
+- Kalender : Kalender, Termine, -, Meine Aufgaben, To-Do-Liste, -, Meine Anwesenheiten, Meine erhaltenen Einladungen, -, Erwartete Besucher, Wartende Besucher
 
 - DSBE : Klienten, VSEs, Art.60§7-Konventionen, Stellenanbieter, Stellen, Stellenangebote, Übersicht Art.60§7-Konventionen, Tätigkeitsbericht
 
@@ -632,6 +636,7 @@ Belgique""")
   - DSBE : VSE-Arten, Vertragsbeendigungsgründe, Auswertungsstrategien, Ausbildungsarten, Art.60§7-Konventionsarten, Stellenarten, Sektoren, Funktionen, Stundenpläne, Regimes
   - Kurse : Kursinhalte
   - Neuanträge : Vermittler, Fachbereiche
+  - Schuldnerberatung : Budget-Kopiervorlage
   - ZDSS : Sektoren, Eigenschafts-Codes
 
 - Explorer :
@@ -664,9 +669,9 @@ Belgique""")
   - Postsendungen : Meine Postsendungen, Bereit für Ausdruck, Gedruckte Postsendungen, Ausgegangene Postsendungen
   - Meine Notizen
 
-- Kalender : Kalender, Termine, -, Meine Aufgaben, To-Do-Liste, -, Meine Anwesenheiten, Meine erhaltenen Einladungen
+- Kalender : Kalender, Termine, -, Meine Aufgaben, To-Do-Liste, -, Meine Anwesenheiten, Meine erhaltenen Einladungen, -, Wartende Besucher
 
-- DSBE : Klienten, VSEs, Art.60§7-Konventionen, Stellenanbieter, Stellen, Stellenangebote, Übersicht Art.60§7-Konventionen
+- DSBE : Klienten, VSEs, Art.60§7-Konventionen, Stellenanbieter, Stellen, Stellenangebote, Übersicht Art.60§7-Konventionen, Tätigkeitsbericht
 
 - Kurse : Kursanbieter, Kursangebote, Offene Kursanfragen
 
@@ -684,7 +689,45 @@ Belgique""")
 - Site : Info
 """) # 100 integration agent
 
-        # debts consultant
+        # 110 integration agent (manager)
+        menu_test("110","""\
+- Kontakte : Personen,  ▶ Klienten, Organisationen, Haushalte, -, Partner (alle)
+
+- Büro :
+  
+  - Mein E-Mail-Ausgang
+  - Postsendungen : Meine Postsendungen, Bereit für Ausdruck, Gedruckte Postsendungen, Ausgegangene Postsendungen
+  - Meine Notizen
+
+- Kalender : Kalender, Termine, -, Meine Aufgaben, To-Do-Liste, -, Meine Anwesenheiten, Meine erhaltenen Einladungen, -, Wartende Besucher
+
+- DSBE : Klienten, VSEs, Art.60§7-Konventionen, Stellenanbieter, Stellen, Stellenangebote, Übersicht Art.60§7-Konventionen, Tätigkeitsbericht
+
+- Kurse : Kursanbieter, Kursangebote, Offene Kursanfragen
+
+- Listings : Benutzer und ihre Klienten
+
+- Konfigurierung :
+  
+  - Büro : Meine Einfügetexte
+  - Kontakte : Länder, Sprachen
+  - Kalender : Räume, Prioritäten, Kalenderliste
+  - ÖSHZ : Integrationsphasen, Begleitungsbeendigungsgründe, Dispenzgründe
+  - DSBE : VSE-Arten, Vertragsbeendigungsgründe, Auswertungsstrategien, Art.60§7-Konventionsarten, Stellenarten, Sektoren, Funktionen, Stundenpläne, Regimes
+  - Kurse : Kursinhalte
+
+- Explorer :
+  
+  - Büro : E-Mail-Ausgänge, Anhänge, Postsendungen
+  - Kalender : Aufgaben, Abonnements
+  - CV : Sprachkenntnisse
+  - DSBE : VSEs, Art.60§7-Konventionen, Stellenanfragen, Ausbildungen und Studien
+  - Kurse : Kursanfragen
+
+- Site : Info
+""") # 110 integration agent (manager)
+
+        # 300 debts consultant
         menu_test('300',"""\
 - Kontakte : Personen,  ▶ Klienten, Organisationen, Haushalte, -, Partner (alle)
 
@@ -694,7 +737,7 @@ Belgique""")
   - Postsendungen : Meine Postsendungen, Bereit für Ausdruck, Gedruckte Postsendungen, Ausgegangene Postsendungen
   - Meine Notizen
 
-- Kalender : Kalender, Termine, -, Meine Aufgaben, To-Do-Liste, -, Meine Anwesenheiten, Meine erhaltenen Einladungen
+- Kalender : Kalender, Termine, -, Meine Aufgaben, To-Do-Liste, -, Meine Anwesenheiten, Meine erhaltenen Einladungen, -, Wartende Besucher
 
 - Schuldnerberatung : Klienten, Meine Budgets
 
@@ -702,11 +745,12 @@ Belgique""")
   
   - Büro : Meine Einfügetexte
   - Kontakte : Länder, Sprachen
+  - Schuldnerberatung : Budget-Kopiervorlage
 
 - Site : Info
 """) # 300 debts consultant
 
-        # newcomers
+        # 200 newcomers
         menu_test('200',"""\
 - Kontakte : Personen,  ▶ Klienten, Organisationen, Haushalte, -, Partner (alle)
 
@@ -716,7 +760,7 @@ Belgique""")
   - Postsendungen : Meine Postsendungen, Bereit für Ausdruck, Gedruckte Postsendungen, Ausgegangene Postsendungen
   - Meine Notizen
 
-- Kalender : Kalender, Termine, -, Meine Aufgaben, To-Do-Liste, -, Meine Anwesenheiten, Meine erhaltenen Einladungen
+- Kalender : Kalender, Termine, -, Meine Aufgaben, To-Do-Liste, -, Meine Anwesenheiten, Meine erhaltenen Einladungen, -, Erwartete Besucher, Wartende Besucher
 
 - Neuanträge : Neue Klienten
 
@@ -730,3 +774,10 @@ Belgique""")
 - Site : Info
 """) # 200 newcomers
 
+
+
+        #~ kw = dict(id=1,user=User.objects.get(username='300'))
+        #~ kw.update(partner=)
+        #~ mb = debts.Budget(**kw)
+        #~ mb.save()
+        #~ settings.SITE.site_config.master_budget = mb
